# -*- coding: utf-8 -*-
from django.urls import path
from vacancies.views import VacancyList, VacancyDetailView

urlpatterns = [
    path('', VacancyList.as_view()),
    path('<slug:slug>/', VacancyDetailView.as_view(), name='vacancy-detail'),
]



# -*- coding: utf-8 -*-
from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class VacanciesConfig(AppConfig):
    name = 'vacancies'
    verbose_name = _('Vacancies Config')



# -*- coding: utf-8 -*-
from django.core.validators import FileExtensionValidator
from django.db import models
from django.urls import reverse
from django.utils.translation import ugettext_lazy as _

from vacancies.storage import vacancy_pdf, vacancy_image
from vacancies.utils import generate_unique_slug


class Vacancy(models.Model):

    MANAGEMENT_RESPONSIBILITY_NONE = 1
    MANAGEMENT_RESPONSIBILITY_ALL = 2
    MANAGEMENT_RESPONSIBILITY_TEAM = 3
    MANAGEMENT_RESPONSIBILITY_DEPARTMENT = 4
    MANAGEMENT_RESPONSIBILITY_BOARD = 5
    MANAGEMENT_RESPONSIBILITY_STAFF = 6
    MANAGEMENT_RESPONSIBILITY_CHOICES = (
        (MANAGEMENT_RESPONSIBILITY_NONE, _('No management responsibility')),
        (MANAGEMENT_RESPONSIBILITY_ALL, _('All management levels')),
        (MANAGEMENT_RESPONSIBILITY_TEAM, _('Team management, project management, group management')),
        (MANAGEMENT_RESPONSIBILITY_DEPARTMENT, _('Head of Department, Division Management, Department Management')),
        (MANAGEMENT_RESPONSIBILITY_BOARD, _('Management, board, management')),
        (MANAGEMENT_RESPONSIBILITY_STAFF, _('Staff function')),
    )

    WORK_EXPERIENCE_ENTRY = 1
    WORK_EXPERIENCE_EXPERIENCE = 2
    WORK_EXPERIENCE_CHOICES = (
        (WORK_EXPERIENCE_ENTRY, _('Entry level')),
        (WORK_EXPERIENCE_EXPERIENCE, _('With professional experience')),
    )

    additional_working_hours_information = models.TextField(blank=True, verbose_name=_('Additional working hours information'))
    available_positions = models.IntegerField(default=1, blank=True, null=True, verbose_name=_('Available positions'))
    box_number = models.CharField(max_length=255, blank=True, verbose_name=_('Box Number'))
    collective_agreement = models.CharField(max_length=255, blank=True, verbose_name=_('Collective agreement'))
    compensation = models.CharField(max_length=255, blank=True, verbose_name=_('Compensation'))
    contact_person = models.ForeignKey('ContactPerson', null=True, blank=True, on_delete=models.SET_NULL, related_name='job_offers', verbose_name=_('Contact Person'))
    created_at = models.DateTimeField(auto_now_add=True, verbose_name=_('Created at'))
    description = models.TextField(blank=True, verbose_name=_('Description'))
    earliest_start = models.DateField(blank=True, null=True, verbose_name=_('Earliest start'))
    hours_per_week = models.IntegerField(blank=True, null=True, verbose_name=_('Hours per week'))
    image = models.ImageField(upload_to=vacancy_image, null=True, blank=True, verbose_name=_('Image'))
    is_public = models.BooleanField(default=False, verbose_name=_('Is public'))
    latest_start = models.DateField(blank=True, null=True, verbose_name=_('Latest start'))
    limited_to = models.DateField(blank=True, null=True, verbose_name=_('Limited to'))
    locations = models.ManyToManyField('Location', blank=True, related_name='vacancies', verbose_name=_('Locations'))
    management_responsibility = models.PositiveSmallIntegerField(choices=MANAGEMENT_RESPONSIBILITY_CHOICES, blank=True, null=True, verbose_name=_('Management responsibility'))
    marginal_employment = models.BooleanField(default=False, verbose_name=_('Marginal employment'))
    max_distance = models.IntegerField(blank=True, null=True, help_text=_('km/miles'), verbose_name=_('Max Distance'))
    pdf_version = models.FileField(blank=True, null=True, upload_to=vacancy_pdf, validators=[FileExtensionValidator(allowed_extensions=['pdf'])], verbose_name=_('Pdf version'))
    slug = models.SlugField(max_length=250, unique=True)
    social_insurance_employment = models.BooleanField(null=True, verbose_name=_('Social insurance employment'))
    suitable_to_support_the_integration_of_immigrants = models.BooleanField(default=False, verbose_name=_('Suitable to support the integration of immigrants'))
    tariff_commitment = models.BooleanField(default=False, verbose_name=_('Tariff commitment'))
    temporary_for_month = models.PositiveSmallIntegerField(blank=True, null=True, verbose_name=_('Temporary for month'))
    title = models.CharField(max_length=255, verbose_name=_('Title'))
    updated_at = models.DateTimeField(auto_now=True, verbose_name=_('Updated at'))
    work_experience = models.PositiveSmallIntegerField(choices=WORK_EXPERIENCE_CHOICES, blank=True, null=True, verbose_name=_('Work experience'))
    working_hours_full_time = models.BooleanField(default=False, verbose_name=_('Full time'))
    working_hours_night_work = models.BooleanField(default=False, verbose_name=_('Night work'))
    working_hours_part_time_afternoon = models.BooleanField(default=False, verbose_name=_('Part time (afternoon)'))
    working_hours_part_time_eve = models.BooleanField(default=False, verbose_name=_('Part time (eve)'))
    working_hours_part_time_flexible = models.BooleanField(default=False, verbose_name=_('Part time (flexible)'))
    working_hours_part_time_morning = models.BooleanField(default=False, verbose_name=_('Part time (morning)'))
    working_hours_part_time_shift = models.BooleanField(default=False, verbose_name=_('Part time (shift)'))
    working_hours_shift = models.BooleanField(default=False, verbose_name=_('Shift'))
    working_hours_telework = models.BooleanField(default=False, verbose_name=_('Telework'))
    working_hours_weekend = models.BooleanField(default=False, verbose_name=_('Weekend'))

    class Meta:
        verbose_name = _('Vacancy')
        verbose_name_plural = _('Vacancies')

    def __str__(self):
        return self.title

    def get_absolute_url(self):
        return reverse('vacancy-detail', kwargs={'slug': self.slug})

    def save(self, *args, **kwargs):
        if not self.pk:
            self.slug = generate_unique_slug(Vacancy, self.title)

        super().save(*args, **kwargs)



# -*- coding: utf-8 -*-
from django.db import models
from django.utils.translation import ugettext_lazy as _

from vacancies.storage import contact_person_image


class ContactPerson(models.Model):

    SALUTATION_MRS = 1
    SALUTATION_MR = 2
    SALUTATION_CHOICES = (
        (SALUTATION_MRS, _('Mrs')),
        (SALUTATION_MR, _('Mr')),
    )

    company_name = models.CharField(max_length=255, blank=True, verbose_name=_('Company Name'))
    email = models.EmailField(blank=True, verbose_name=_('Email'))
    fax = models.CharField(max_length=255, blank=True, verbose_name=_('Fax'))
    first_name = models.CharField(max_length=255, blank=True, verbose_name=_('First name'))
    image = models.ImageField(upload_to=contact_person_image, null=True, blank=True, verbose_name=_('Image'))
    last_name = models.CharField(max_length=255, blank=True, verbose_name=_('Last name'))
    mobile = models.CharField(max_length=255, blank=True, verbose_name=_('Mobile'))
    name = models.CharField(max_length=255, blank=True, verbose_name=_('First name'))
    phone = models.CharField(max_length=255, blank=True, verbose_name=_('Phone'))
    position = models.CharField(max_length=255, blank=True, verbose_name=_('Position'))
    salutation = models.PositiveSmallIntegerField(choices=SALUTATION_CHOICES, default=SALUTATION_MRS, verbose_name=_('Salutation'))

    class Meta:
        verbose_name = _('Contact person')
        verbose_name_plural = _('Contact persons')

    def __str__(self):
        return self.full_name

    @property
    def full_name(self):
        if self.first_name or self.last_name:
            return '%s %s %s'.strip() % (self.get_salutation_display(), self.first_name, self.last_name)

        return '%s' % self.pk
    full_name.fget.short_description = _('Full name')



# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.safestring import mark_safe
from django.utils.translation import ugettext_lazy as _

from vacancies.models import ContactPerson, Location, Vacancy


@admin.register(Vacancy)
class VacancyAdmin(admin.ModelAdmin):

    save_as = True

    list_display = (
        'title',
        'slug',
        'earliest_start',
        'hours_per_week',
        'is_public',
    )

    list_filter = (
        'is_public',
    )

    readonly_fields = (
        'image_preview',
    )

    filter_horizontal = (
        'locations',
    )

    prepopulated_fields = {
        "slug": ("title",)
    }

    fieldsets = (
        (_('Base Data'), {'classes': ('collapse',), 'fields': (
            'is_public',
            'title',
            'contact_person',
            'description',
            ('earliest_start', 'latest_start'),
        )}),
        (_('Qualifications & Requirements'), {'classes': ('collapse',), 'fields': (
            'work_experience',
            'management_responsibility',
            'max_distance',
        )}),
        (_('Conditions'), {'classes': ('collapse',), 'fields': (
            ('tariff_commitment', 'marginal_employment'),
            'social_insurance_employment',
            'collective_agreement',
            'compensation',
            'temporary_for_month',
            'limited_to',
        )}),
        (_('Working hours'), {'classes': ('collapse',), 'fields': (
            (
                'working_hours_part_time_flexible',
                'working_hours_part_time_shift',
                'working_hours_part_time_morning',
                'working_hours_part_time_afternoon',
                'working_hours_part_time_eve',
                'working_hours_full_time',
                'working_hours_shift',
                'working_hours_night_work',
                'working_hours_weekend',
                'working_hours_telework',
            ),
            'hours_per_week',
            'additional_working_hours_information',
        )}),
        (_('Locations'), {'classes': ('collapse',), 'fields': (
            'locations',
        )}),
        (_('Meta data'), {'classes': ('collapse',), 'fields': (
            'suitable_to_support_the_integration_of_immigrants',
            'available_positions',
            'box_number',
            'slug',
        )}),
        (_('Alternative representations'), {'classes': ('collapse',), 'fields': (
            'image_preview',
            'image',
            'pdf_version',
        )}),
    )

    def image_preview(self, contact_person):
        if not contact_person.image:
            return ''

        return mark_safe(u'<a href="%s" target="_blank" class="profileImage"><img src="%s" height="32"></a>' % (
            contact_person.image.url,
            contact_person.image.url,
        ))
    image_preview.short_description = _('Image preview')

    class Media:
        css = {
            'all': ('vacancies/css/admin.css',)
        }


@admin.register(ContactPerson)
class ContactPersonAdmin(admin.ModelAdmin):

    list_display = (
        'full_name',
        'email',
        'phone',
        'mobile',
        'image_preview',
    )

    list_filter = (
        'salutation',
    )

    readonly_fields = (
        'full_name',
        'image_preview',
    )

    fieldsets = (
        (None, {'fields': (
            'image_preview',
            'salutation',
            ('first_name', 'last_name'),
            ('phone', 'mobile'),
            ('email', 'fax'),
            ('company_name', 'position'),
            'image',
        )}),
    )

    def image_preview(self, contact_person):
        if not contact_person.image:
            return ''

        return mark_safe(u'<a href="%s" target="_blank" class="profileImage"><img src="%s" height="32"></a>' % (
            contact_person.image.url,
            contact_person.image.url,
        ))
    image_preview.short_description = _('Image preview')

    class Media:
        css = {
            'all': ('vacancies/css/admin.css',)
        }


@admin.register(Location)
class LocationAdmin(admin.ModelAdmin):

    list_display = (
        'label',
        'street',
        'zip_code',
        'city',
        'country',
    )

    list_filter = (
        'city',
    )

    fieldsets = (
        (None, {'fields': (
            'label',
            'street',
            'zip_code',
            'city',
            'country',
        )}),
    )



# -*- coding: utf-8 -*-
import os
import hashlib
from django.utils.text import slugify


def contact_person_image(instance, filename):
    _, ext = os.path.splitext(filename)
    uu = hashlib.md5(instance.image.read()).hexdigest()
    return '/'.join(['vacancies', 'contact_persons', uu[:2], uu[2:4], uu, slugify(instance.full_name) + ext.lower()])


def vacancy_pdf(instance, filename):
    uu = hashlib.md5(instance.pdf_version.read()).hexdigest()
    return '/'.join(['vacancies', 'pdf_versions', uu[:2], uu[2:4], uu[4:8], uu + '.pdf'])


def vacancy_image(instance, filename):
    _, ext = os.path.splitext(filename)
    uu = hashlib.md5(instance.image.read()).hexdigest()
    return '/'.join(['vacancies', 'images', uu[:2], uu[2:4], uu, slugify(instance.title) + ext.lower()])



# -*- coding: utf-8 -*-
from django.db import models
from django.utils.translation import ugettext_lazy as _


class Location(models.Model):

    label = models.CharField(max_length=255, blank=True, verbose_name=_('Label'))
    city = models.CharField(max_length=100, verbose_name=_('City'))
    country = models.CharField(max_length=100, blank=True, verbose_name=_('Country'))
    street = models.CharField(max_length=100, blank=True, verbose_name=_('Street'))
    zip_code = models.CharField(max_length=25, blank=True, verbose_name=_('Zip Code'))

    class Meta:
        verbose_name = _('Location')
        verbose_name_plural = _('Locations')

    def __str__(self):
        if self.label:
            return self.label

        return '%s %s %s'.strip() % (
            self.street,
            self.zip_code,
            self.city,
        )



# Generated by Django 2.2 on 2019-11-27 02:53

import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import vacancies.storage


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ContactPerson',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('company_name', models.CharField(blank=True, max_length=255, verbose_name='Company Name')),
                ('email', models.EmailField(blank=True, max_length=254, verbose_name='Email')),
                ('fax', models.CharField(blank=True, max_length=255, verbose_name='Fax')),
                ('first_name', models.CharField(blank=True, max_length=255, verbose_name='First name')),
                ('image', models.ImageField(blank=True, null=True, upload_to=vacancies.storage.contact_person_image, verbose_name='Image')),
                ('last_name', models.CharField(blank=True, max_length=255, verbose_name='Last name')),
                ('mobile', models.CharField(blank=True, max_length=255, verbose_name='Mobile')),
                ('name', models.CharField(blank=True, max_length=255, verbose_name='First name')),
                ('phone', models.CharField(blank=True, max_length=255, verbose_name='Phone')),
                ('position', models.CharField(blank=True, max_length=255, verbose_name='Position')),
                ('salutation', models.PositiveSmallIntegerField(choices=[(1, 'Mrs'), (2, 'Mr')], default=1, verbose_name='Salutation')),
            ],
            options={
                'verbose_name': 'Contact person',
                'verbose_name_plural': 'Contact persons',
            },
        ),
        migrations.CreateModel(
            name='Location',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.CharField(blank=True, max_length=255, verbose_name='Label')),
                ('city', models.CharField(max_length=100, verbose_name='City')),
                ('country', models.CharField(blank=True, max_length=100, verbose_name='Country')),
                ('street', models.CharField(blank=True, max_length=100, verbose_name='Street')),
                ('zip_code', models.CharField(blank=True, max_length=25, verbose_name='Zip Code')),
            ],
            options={
                'verbose_name': 'Location',
                'verbose_name_plural': 'Locations',
            },
        ),
        migrations.CreateModel(
            name='Vacancy',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('additional_working_hours_information', models.TextField(blank=True, verbose_name='Additional working hours information')),
                ('available_positions', models.IntegerField(blank=True, default=1, null=True, verbose_name='Available positions')),
                ('box_number', models.CharField(blank=True, max_length=255, verbose_name='Box Number')),
                ('collective_agreement', models.CharField(blank=True, max_length=255, verbose_name='Collective agreement')),
                ('compensation', models.CharField(blank=True, max_length=255, verbose_name='Compensation')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('description', models.TextField(blank=True, verbose_name='Description')),
                ('earliest_start', models.DateField(blank=True, null=True, verbose_name='Earliest start')),
                ('hours_per_week', models.IntegerField(blank=True, null=True, verbose_name='Hours per week')),
                ('image', models.ImageField(blank=True, null=True, upload_to=vacancies.storage.vacancy_image, verbose_name='Image')),
                ('is_public', models.BooleanField(default=False, verbose_name='Is public')),
                ('latest_start', models.DateField(blank=True, null=True, verbose_name='Latest start')),
                ('limited_to', models.DateField(blank=True, null=True, verbose_name='Limited to')),
                ('management_responsibility', models.PositiveSmallIntegerField(blank=True, choices=[(1, 'No management responsibility'), (2, 'All management levels'), (3, 'Team management, project management, group management'), (4, 'Head of Department, Division Management, Department Management'), (5, 'Management, board, management'), (6, 'Staff function')], null=True, verbose_name='Management responsibility')),
                ('marginal_employment', models.BooleanField(default=False, verbose_name='Marginal employment')),
                ('max_distance', models.IntegerField(blank=True, help_text='km/miles', null=True, verbose_name='Max Distance')),
                ('pdf_version', models.FileField(blank=True, null=True, upload_to=vacancies.storage.vacancy_pdf, validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['pdf'])], verbose_name='Pdf version')),
                ('slug', models.SlugField(max_length=250, unique=True)),
                ('social_insurance_employment', models.BooleanField(null=True, verbose_name='Social insurance employment')),
                ('suitable_to_support_the_integration_of_immigrants', models.BooleanField(default=False, verbose_name='Suitable to support the integration of immigrants')),
                ('tariff_commitment', models.BooleanField(default=False, verbose_name='Tariff commitment')),
                ('temporary_for_month', models.PositiveSmallIntegerField(blank=True, null=True, verbose_name='Temporary for month')),
                ('title', models.CharField(max_length=255, verbose_name='Title')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='Updated at')),
                ('work_experience', models.PositiveSmallIntegerField(blank=True, choices=[(1, 'Entry level'), (2, 'With professional experience')], null=True, verbose_name='Work experience')),
                ('working_hours_full_time', models.BooleanField(default=False, verbose_name='Full time')),
                ('working_hours_night_work', models.BooleanField(default=False, verbose_name='Night work')),
                ('working_hours_part_time_afternoon', models.BooleanField(default=False, verbose_name='Part time (afternoon)')),
                ('working_hours_part_time_eve', models.BooleanField(default=False, verbose_name='Part time (eve)')),
                ('working_hours_part_time_flexible', models.BooleanField(default=False, verbose_name='Part time (flexible)')),
                ('working_hours_part_time_morning', models.BooleanField(default=False, verbose_name='Part time (morning)')),
                ('working_hours_part_time_shift', models.BooleanField(default=False, verbose_name='Part time (shift)')),
                ('working_hours_shift', models.BooleanField(default=False, verbose_name='Shift')),
                ('working_hours_telework', models.BooleanField(default=False, verbose_name='Telework')),
                ('working_hours_weekend', models.BooleanField(default=False, verbose_name='Weekend')),
                ('contact_person', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='job_offers', to='vacancies.ContactPerson', verbose_name='Contact Person')),
                ('locations', models.ManyToManyField(blank=True, related_name='vacancies', to='vacancies.Location', verbose_name='Locations')),
            ],
            options={
                'verbose_name': 'Vacancy',
                'verbose_name_plural': 'Vacancies',
            },
        ),
    ]



# -*- coding: utf-8 -*-
from django.utils.text import slugify


def generate_unique_slug(klass, field):

    origin_slug = slugify(field)
    unique_slug = origin_slug
    loop_interval = 1

    while klass.objects.filter(slug=unique_slug).exists():
        unique_slug = '%s-%d' % (origin_slug, loop_interval)
        loop_interval += 1

    return unique_slug



# -*- coding: utf-8 -*-
from django.views.generic import ListView, DetailView
from vacancies.models import Vacancy


class VacancyList(ListView):
    queryset = Vacancy.objects.filter(is_public=True)
    context_object_name = 'public_vacancies'


class VacancyDetailView(DetailView):
    context_object_name = 'vacancy'
    queryset = Vacancy.objects.filter(is_public=True)
